Documentation
¶
Overview ¶
Package nrfiber provides New Relic instrumentation for the Fiber web framework.
Index ¶
- func ConfigCustomTransactionNameFunc(customTransactionNameFunc func(c *fiber.Ctx) string) *config
- func ConfigNoticeErrorEnabled(enabled bool) *config
- func ConfigStatusCodeIgnored(statusCode []int) *config
- func FromContext(c *fiber.Ctx) *newrelic.Transaction
- func Middleware(app *newrelic.Application, configs ...*config) fiber.Handler
- func Send(c *fiber.Ctx, segmentName string)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ConfigCustomTransactionNameFunc ¶ added in v0.1.3
func ConfigNoticeErrorEnabled ¶
func ConfigNoticeErrorEnabled(enabled bool) *config
func ConfigStatusCodeIgnored ¶
func ConfigStatusCodeIgnored(statusCode []int) *config
func FromContext ¶
func FromContext(c *fiber.Ctx) *newrelic.Transaction
FromContext returns the Transaction from the context if present, and nil otherwise.
func Middleware ¶
func Middleware(app *newrelic.Application, configs ...*config) fiber.Handler
Middleware creates Fiber middleware that instrument's requests.
app := fiber.New() // Add the nrfiber middleware before other middlewares or routes: app.Use(nrfiber.Middleware(app))
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.